Receiver

Struct Receiver 

pub struct Receiver { /* private fields */ }
Receiver for an AF_XDP socket.

Implementations

Source

impl Receiver

pub fn recv(&mut self) -> Result<RouteEvent<'_>, ChannelError>

Blocks until a packet is available. This returns a RouteEvent, which references the underlying memory. It should quickly be dropped or converted into an crate::events::route::OwnedRouteEvent to avoid frame starvation.

Errors

Returns ChannelError::Disconnected if the channel is closed.

pub fn try_recv(&mut self) -> Result<RouteEvent<'_>, ChannelError>

Attempts to receive a packet. This returns a RouteEvent, which references the underlying memory. It should quickly be dropped or converted into an crate::events::route::OwnedRouteEvent to avoid frame starvation.

Errors

Returns ChannelError::Disconnected if the channel is closed. Returns ChannelError::Empty if there are no packets available.