CopyEvent

Struct CopyEvent 

pub struct CopyEvent<'a>(/* private fields */);
A packet event captured with crate::rules::Action::Copy. This will block the ring buffer until it is dropped, so it should be consumed quickly. Calling CopyEvent::into_owned returns an OwnedCopyEvent, dropping the underlying RingBufItem at the cost of a copy.

Implementations

Source

impl CopyEvent<'_>

pub fn take(&self) -> Option<u32>

If set, returns the number of bytes copied. This may be lower than the originally specified value, if the packet is less than the original take.

pub fn rule_id(&self) -> RuleId

Returns the RuleId that the packet matched on

pub fn packet_len(&self) -> u32

Returns the length of the packet data, before take is applied

pub fn data_len(&self) -> u32

Returns the length of the data, after take has been applied

pub fn data(&self) -> &[u8]

Returns the raw data copied from the packet

pub fn into_owned(self) -> OwnedCopyEvent

Converts to an OwnedCopyEvent, dropping the underlying RingBufItem which frees capacity for successive writes.