OwnedCopyEvent

Struct OwnedCopyEvent 

pub struct OwnedCopyEvent { /* private fields */ }
An owned copy event contains a Box containing copied data from the RingBufItem. This allows working with the data why freeing up capacity for the aya::maps::RingBuf.

Implementations

Source

impl OwnedCopyEvent

pub fn take(&self) -> Option<u32>

If set, returns the number of bytes copied. This may be lower than the originally specified value, if the packet is less than the original take.

pub fn rule_id(&self) -> RuleId

Returns the RuleId that the packet matched on

pub fn packet_len(&self) -> u32

Returns the length of the packet data, before take is applied

pub fn data_len(&self) -> u32

Returns the length of the data, after take has been applied

pub fn data(&self) -> &[u8]

Returns the raw data copied from the packet