RouteEvent

Struct RouteEvent 

pub struct RouteEvent<'a> { /* private fields */ }
A packet event captured with crate::rules::Action::Route. This will take a frame in the AF_AXP socket until it is dropped, so it should be consumed quickly. Calling RouteEvent::into_owned returns an OwnedRouteEvent, releasing the frame at the cost of a copy.

Implementations

Source

impl RouteEvent<'_>

pub fn rule_id(&self) -> RuleId

Returns the RuleId that the packet matched on

pub fn data(&self) -> &[u8]

Returns the raw packet data

pub fn into_owned(self) -> OwnedRouteEvent

Converts to an OwnedRouteEvent, releasing the underlying AF_XDP socket frame.