Rule definitions and builders.
Structs
- Rule
- A rule for controlling packet routing. Rules can be build with
RuleBuilderand require at least one filter constraint, and an action. - Rule
Builder - A builder struct for
Rules. This should generally be constructed withRule::builder, or a shortcut such asRule::source_cidr. - RuleId
- ID for a
Rule. This can be used to track rules for dynamic removal. RemovedRuleIds are reclaimed.