#[non_exhaustive]pub enum Action {
Pass,
Drop,
Copy {
take: Option<u32>,
},
Route,
}Expand description
An action to take on matching rules.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Pass
Instructs the kernel to do nothing, and should be used to override other rules.
Drop
Drops the packet.
Copy
Copies the packet to userspace, but it is processed as normal by the kernel. The take
field optionally limits the copied data to a certain number of bytes.
Route
Routes the packet to userspace.
Implementations