RuleBuilder

Struct RuleBuilder 

pub struct RuleBuilder { /* private fields */ }
A builder struct for Rules. This should generally be constructed with Rule::builder, or a shortcut such as Rule::source_cidr.

Implementations

Source

impl RuleBuilder

pub fn action(self, action: Action) -> Self

Sets the rule’s Action

The action applies to all packets matching the rule, unless overridden by successive rules.

pub fn protocol(self, protocol: Protocol) -> Self

Sets the rule’s Protocol

pub fn source_cidr(self, cidr_range: impl IntoIpNet) -> Self

Sets the source CIDR.

Accepts any IP address or CIDR notation:

  • "127.0.0.1": matches a single IP
  • "10.0.0.0/24": matches a CIDR

This additionally accepts std::net::IpAddr, std::net::Ipv4Addr, std::net::Ipv6Addr, ipnet::IpNet, ipnet::Ipv4Net, and ipnet::Ipv6Net.

pub fn source_port(self, port: impl IntoPortRange) -> Self

Sets the source port

Accepts a u16 or range

pub fn destination_cidr(self, cidr_range: impl IntoIpNet) -> Self

Sets the destination CIDR.

Accepts any IP address or CIDR notation:

  • "127.0.0.1": matches a single IP
  • "10.0.0.0/24": matches a CIDR

This additionally accepts std::net::IpAddr, std::net::Ipv4Addr, std::net::Ipv6Addr, ipnet::IpNet, ipnet::Ipv4Net, and ipnet::Ipv6Net.

pub fn destination_port(self, port: impl IntoPortRange) -> Self

Sets the destination port

Accepts a u16 or range

pub fn build(self) -> Result<Rule, RuleError>

Builds the Rule.

Errors

Returns an RuleError if there is a missing action, invalid cidr, or no constraints (ips, ports, protocols).