Interface

Struct Interface 

pub struct Interface { /* private fields */ }
A network interface

Implementations

Source

impl Interface

pub fn from_name(name: &str) -> Result<Self, Error>

Creates an interface from the name

Errors

Returns Error::InvalidInterfaceName if the name is invalid.

pub fn from_index(index: u32) -> Result<Self, Error>

Creates an interface from the index

Errors

Returns Error::InvalidInterfaceIndex if the index is invalid. Returns Error::InvalidInterfaceName if the name is invalid.

Panics

Panics if the interface name is not a valid string

pub fn name(&self) -> &str

Returns the interface name

pub fn index(&self) -> u32

Returns the interface index

pub fn frame_kind(&self) -> Result<FrameKind, Error>

Returns the interfaces FrameKind. This is needed because most interfaces receive ethernet frames, while wireguard interfaces receive IP frames.

Errors

Returns Error::InvalidFrameKind if the FrameKind is not FrameKind::Eth or FrameKind::Ip.