RouteConfig

Struct RouteConfig 

pub struct RouteConfig { /* private fields */ }
Optional configuration for routing packets.

Presently, AF_XDP routing is configured with a shared UMEM region, with a queue serving as a free list to coordinate available frames.

This Defaults to the following:

  • force_enabled: false
  • umem_config.fill_size: 2048 frames
  • umem_config.complete_size: 2048 frames
  • umem_config.frame_size: 4096 bytes
  • umem_config.headroom: 32 bytes
  • umem_config.flags: 0
  • socket_config.rx_size: 2048 frames
  • socket_config.tx_size: 2048 frames
  • socket_config.bind_flags: SocketConfig::XDP_BIND_NEED_WAKEUP
  • frame_count: 8192
  • queue_id: 0

Implementations

Source

impl RouteConfig

pub fn force_enabled(self) -> Self

Force the Tap to provision route primitives, even if no rules use route. Set this if you want to dynamically add a rule with Action::Route later.

pub fn umem_config(self, umem_config: UmemConfig) -> Self

Overrides the default UmemConfig for the AF_XDP socket.

pub fn socket_config(self, socket_config: SocketConfig) -> Self

Overrides the default SocketConfig for the AF_XDP socket.

pub fn frame_count(self, frame_count: u32) -> Self

Sets the frame_count for the AF_XDP socket. Combined with the UmemConfig settings, this will determine the total size of the Umem region.

pub fn queue_id(self, queue_id: u32) -> Self

Sets the queue_id for the AF_XDP socket.

Note

The queue_id is likely not going to contain all of the traffic you expect unless you specifially route traffic to that queue id, for example, using ethtool. https://www.kernel.org/doc/html/latest/networking/af_xdp.html#faq