Tap

Struct Tap 

pub struct Tap<E: Engine = LinearEngine> { /* private fields */ }
Taps into a network interface. This struct stores all eBPF primitives required for the specific combination of Actions and the Engine. It defaults to using a LinearEngine.

Implementations

Source

impl Tap

pub fn builder<I>(interface: I) -> TapBuilder
where I: TryInto<Interface>, I::Error: Into<Error>,

Creates a new TapBuilder with the specified Interface.

Source

impl<E: Engine> Tap<E>

pub fn frame_kind(&self) -> FrameKind

Returns the FrameKind for the selected interface

pub fn route_channel(&mut self) -> Result<(Sender, Receiver), Error>

Returns a tuple of channels::route::Sender and channels::route::Receiver.

Errors

Returns Error::RouteNotEnabled if routing is not enabled. Returns Error::ChannelNotAvailable if the channel has already been taken.

pub fn copy_receiver(&mut self) -> Result<Receiver, Error>

Returns a channels::copy::Receiver for receiving data.

Errors

Returns Error::CopyNotEnabled if copying is not enabled.. Returns Error::ChannelNotAvailable if the channel has already been taken.

pub fn add_rule<R>(&mut self, rule: R) -> Result<RuleId, Error>
where R: TryInto<Rule>, R::Error: Into<Error>,

Add a Rule or RuleBuilder.

Errors

Returns Error::CopyNotEnabled or Error::RouteNotEnabled if the Tap hasn’t provisioned the required primitives. Returns an Error if the engine cannot add the rule.

pub fn remove_rule(&mut self, rule_id: RuleId) -> Result<Rule, Error>

Remove a Rule by its RuleId.

Errors

Returns Error::MissingRule if the RuleId is invalid. Returns an error if the Engine cannot remove the rule.

pub fn interface(&self) -> &Interface

Access the Interface