pub struct CopyEvent<'a>(/* private fields */);Expand description
A packet event captured with crate::rules::Action::Copy. This will block the ring buffer
until it is dropped, so it should be consumed quickly. Calling
CopyEvent::into_owned returns an OwnedCopyEvent, dropping the underlying RingBufItem
at the cost of a copy.
Implementations
Sourceimpl CopyEvent<'_>
impl CopyEvent<'_>
Sourcepub fn take(&self) -> Option<u32>
pub fn take(&self) -> Option<u32>
If set, returns the number of bytes copied. This may be lower than the originally specified value, if the packet is less than the original take.
Sourcepub fn packet_len(&self) -> u32
pub fn packet_len(&self) -> u32
Returns the length of the packet data, before take is applied
Sourcepub fn into_owned(self) -> OwnedCopyEvent
pub fn into_owned(self) -> OwnedCopyEvent
Converts to an OwnedCopyEvent, dropping the underlying RingBufItem which frees
capacity for successive writes.