pub struct OwnedCopyEvent { /* private fields */ }Expand description
An owned copy event contains a Box containing copied data from the RingBufItem. This allows
working with the data why freeing up capacity for the aya::maps::RingBuf.
Implementations
Sourceimpl OwnedCopyEvent
impl OwnedCopyEvent