pub struct RouteEvent<'a> { /* private fields */ }Expand description
A packet event captured with crate::rules::Action::Route. This will take a frame in the
AF_AXP socket until it is dropped, so it should be consumed quickly. Calling
RouteEvent::into_owned returns an OwnedRouteEvent, releasing the frame at the cost of a
copy.
Implementations
Sourceimpl RouteEvent<'_>
impl RouteEvent<'_>
Sourcepub fn into_owned(self) -> OwnedRouteEvent
pub fn into_owned(self) -> OwnedRouteEvent
Converts to an OwnedRouteEvent, releasing the underlying AF_XDP socket frame.