Module rules

Module rules 

Rule definitions and builders.

Structs

Rule
A rule for controlling packet routing. Rules can be build with RuleBuilder and require at least one filter constraint, and an action.
RuleBuilder
A builder struct for Rules. This should generally be constructed with Rule::builder, or a shortcut such as Rule::source_cidr.
RuleId
ID for a Rule. This can be used to track rules for dynamic removal. Removed RuleIds are reclaimed.

Enums

Action
An action to take on matching rules.
Protocol
Shared protocol, used for setting and executing filter rules
RuleError